@@ -345,6 +345,7 @@ class zetl:
 		#print(sql)
 		data = self.zetldb.db.query(sql)
 		for row in data:
+			consoleoutput = ''
 			stepnum = row[0]
 			steptablename = row[1]
 			cmdfile = row[2]
@@ -611,8 +612,8 @@ class zetldbaccess:
 										self.add_etl_step(etl_name,etl_step,etl_script_file)		
 
 if __name__ == '__main__':
-	#zetl().forcerun('test')
-	main()
+	#main()
+	zetl().forcerun('LoadPostalCodes')
 
 		
 
